django_analyses.models.managers package — django_analyses 0.0.3 documentation

# django_analyses.models.managers package

## Submodules

## django_analyses.models.managers.analysis module

class `django_analyses.models.managers.analysis.` `AnalysisManager`

  Bases: `django.db.models.manager.Manager`

  `from_dict`(definition: dict) → tuple
  `from_list`(definitions: list) → dict

## django_analyses.models.managers.analysis_version module

class `django_analyses.models.managers.analysis_version.` `AnalysisVersionManager`

  Bases: `django.db.models.manager.Manager`

  `from_dict`(analysis, definition: dict)
  `from_list`(analysis, definitions: list) → dict
  `get_kwargs_from_definition`(analysis, definition: dict) → dict

## django_analyses.models.managers.input_definition module

class `django_analyses.models.managers.input_definition.` `InputDefinitionManager`

  Bases: `model_utils.managers.InheritanceManager`

  `from_specification_dict`(specification: dict) → list

## django_analyses.models.managers.input_specification module

class `django_analyses.models.managers.input_specification.` `InputSpecificationManager`

  Bases: `django.db.models.manager.Manager`

  `filter_by_definitions`(analysis, definitions: list) → django.db.models.query.QuerySet
  `from_dict`(analysis, specification: dict) → tuple

## django_analyses.models.managers.output_definition module

class `django_analyses.models.managers.output_definition.` `OutputDefinitionManager`

  Bases: `model_utils.managers.InheritanceManager`

  `from_specification_dict`(specification: dict) → list

## django_analyses.models.managers.output_specification module

class `django_analyses.models.managers.output_specification.` `OutputSpecificationManager`

  Bases: `django.db.models.manager.Manager`

  `filter_by_definitions`(analysis, definitions: list) → django.db.models.query.QuerySet
  `from_dict`(analysis, specification: dict) → tuple

## django_analyses.models.managers.run module

class `django_analyses.models.managers.run.` `RunManager`

  Bases: `django.db.models.manager.Manager`

  `create_and_execute`(analysis_version: django_analyses.models.analysis_version.AnalysisVersion, user: django.contrib.auth.models.User = None, **kwargs)
  `get_existing`(analysis_version: django_analyses.models.analysis_version.AnalysisVersion, **kwargs)
  `get_or_execute`(analysis_version: django_analyses.models.analysis_version.AnalysisVersion, user: django.contrib.auth.models.User = None, **kwargs)

## Module contents